==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/python/IPythonDeps.java <==
package io.github.cdklabs.projen.python;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.894Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.IPythonDeps")
@software.amazon.jsii.Jsii.Proxy(IPythonDeps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IPythonDeps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) A task that installs and updates dependencies.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getInstallTask();

    /**
     * (experimental) Adds a runtime dependency.
     * <p>
     * @param spec Format `<module>@<semver>`. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    void addDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec);

    /**
     * (experimental) Adds a dev dependency.
     * <p>
     * @param spec Format `<module>@<semver>`. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    void addDevDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec);

    /**
     * (experimental) Installs dependencies (called during post-synthesis).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    void installDependencies();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements io.github.cdklabs.projen.python.IPythonDeps.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) A task that installs and updates dependencies.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getInstallTask() {
            return software.amazon.jsii.Kernel.get(this, "installTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
        }

        /**
         * (experimental) Adds a runtime dependency.
         * <p>
         * @param spec Format `<module>@<semver>`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final void addDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
            software.amazon.jsii.Kernel.call(this, "addDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
        }

        /**
         * (experimental) Adds a dev dependency.
         * <p>
         * @param spec Format `<module>@<semver>`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final void addDevDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
            software.amazon.jsii.Kernel.call(this, "addDevDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
        }

        /**
         * (experimental) Installs dependencies (called during post-synthesis).
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final void installDependencies() {
            software.amazon.jsii.Kernel.call(this, "installDependencies", software.amazon.jsii.NativeType.VOID);
        }
    }

    /**
     * Internal default implementation for {@link IPythonDeps}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IPythonDeps {

        /**
         * (experimental) A task that installs and updates dependencies.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getInstallTask() {
            return software.amazon.jsii.Kernel.get(this, "installTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
        }

        /**
         * (experimental) Adds a runtime dependency.
         * <p>
         * @param spec Format `<module>@<semver>`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default void addDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
            software.amazon.jsii.Kernel.call(this, "addDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
        }

        /**
         * (experimental) Adds a dev dependency.
         * <p>
         * @param spec Format `<module>@<semver>`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default void addDevDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
            software.amazon.jsii.Kernel.call(this, "addDevDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
        }

        /**
         * (experimental) Installs dependencies (called during post-synthesis).
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default void installDependencies() {
            software.amazon.jsii.Kernel.call(this, "installDependencies", software.amazon.jsii.NativeType.VOID);
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/python/IPythonDeps.java <==
package io.github.cdklabs.projen.python;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.566Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.IPythonDeps")
@software.amazon.jsii.Jsii.Proxy(IPythonDeps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IPythonDeps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) A task that installs and updates dependencies.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getInstallTask();

    /**
     * (experimental) Adds a runtime dependency.
     * <p>
     * @param spec Format <code>&lt;module&gt;&#64;&lt;semver&gt;</code>. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    void addDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec);

    /**
     * (experimental) Adds a dev dependency.
     * <p>
     * @param spec Format <code>&lt;module&gt;&#64;&lt;semver&gt;</code>. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    void addDevDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec);

    /**
     * (experimental) Installs dependencies (called during post-synthesis).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    void installDependencies();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements io.github.cdklabs.projen.python.IPythonDeps.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) A task that installs and updates dependencies.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getInstallTask() {
            return software.amazon.jsii.Kernel.get(this, "installTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
        }

        /**
         * (experimental) Adds a runtime dependency.
         * <p>
         * @param spec Format <code>&lt;module&gt;&#64;&lt;semver&gt;</code>. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final void addDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
            software.amazon.jsii.Kernel.call(this, "addDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
        }

        /**
         * (experimental) Adds a dev dependency.
         * <p>
         * @param spec Format <code>&lt;module&gt;&#64;&lt;semver&gt;</code>. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final void addDevDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
            software.amazon.jsii.Kernel.call(this, "addDevDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
        }

        /**
         * (experimental) Installs dependencies (called during post-synthesis).
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final void installDependencies() {
            software.amazon.jsii.Kernel.call(this, "installDependencies", software.amazon.jsii.NativeType.VOID);
        }
    }

    /**
     * Internal default implementation for {@link IPythonDeps}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IPythonDeps {

        /**
         * (experimental) A task that installs and updates dependencies.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getInstallTask() {
            return software.amazon.jsii.Kernel.get(this, "installTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
        }

        /**
         * (experimental) Adds a runtime dependency.
         * <p>
         * @param spec Format <code>&lt;module&gt;&#64;&lt;semver&gt;</code>. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default void addDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
            software.amazon.jsii.Kernel.call(this, "addDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
        }

        /**
         * (experimental) Adds a dev dependency.
         * <p>
         * @param spec Format <code>&lt;module&gt;&#64;&lt;semver&gt;</code>. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default void addDevDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
            software.amazon.jsii.Kernel.call(this, "addDevDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
        }

        /**
         * (experimental) Installs dependencies (called during post-synthesis).
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default void installDependencies() {
            software.amazon.jsii.Kernel.call(this, "installDependencies", software.amazon.jsii.NativeType.VOID);
        }
    }
}
